import { __awaiter } from "tslib";
import { useEffect, useState } from 'react';
import { Subject } from 'rxjs';
import { bundledLanguages } from 'shiki/langs';
import { atDotCssGrammar } from './grammar/atDotCss';
import { convoGrammar } from './grammar/convo';
import { mdxGrammar } from './grammar/mdx';
let defaultHighlighter;
const autoLoadMdCodeBlocksKey = 'autoLoadMdCodeBlocks';
const autoLoadMdCodeBlocksList = [
    'markdown',
];
const loadedLangInfo = {};
const loadLangMap = {};
const onLangLoad = new Subject();
export const loadShikiLangAsync = (name) => {
    var _a;
    return (_a = loadLangMap[name]) !== null && _a !== void 0 ? _a : (loadLangMap[name] = _loadShikiLangAsync(0, name));
};
const langDeps = {
//mdx:['tsx'],
//convo:['json','xml','javascript','python'],
};
const _loadShikiLangAsync = (depth, name) => __awaiter(void 0, void 0, void 0, function* () {
    var _a, _b;
    if (depth > 10 || name === 'elm' || name === 'erlang') {
        return false;
    }
    const sh = yield getShikiAsync();
    if (sh.getLoadedLanguages().includes(name)) {
        return false;
    }
    const custom = (name === 'convo' ?
        convoGrammar
        : name === 'atdot' ?
            atDotCssGrammar
            : name === 'mdx' ?
                mdxGrammar
                :
                    null);
    try {
        yield sh.loadLanguage(custom !== null && custom !== void 0 ? custom : name);
        onLangLoad.next(name);
    }
    catch (_c) {
        //
    }
    const bundled = custom ? [custom] : ((_b = (yield ((_a = bundledLanguages[name]) === null || _a === void 0 ? void 0 : _a.call(bundledLanguages)))) === null || _b === void 0 ? void 0 : _b.default);
    const depList = langDeps[name];
    if (depList) {
        for (const dep of depList) {
            yield _loadShikiLangAsync(depth + 1, dep);
        }
    }
    if (bundled) {
        for (const b of bundled) {
            loadedLangInfo[b.name] = {
                embeddedLangsLazy: b.embeddedLangsLazy,
                [autoLoadMdCodeBlocksKey]: b[autoLoadMdCodeBlocksKey] || autoLoadMdCodeBlocksList.includes(b.name),
            };
            if (b.embeddedLangs) {
                for (const e of b.embeddedLangs) {
                    yield _loadShikiLangAsync(depth + 1, e);
                }
            }
        }
    }
    return true;
});
export const supportsMdCodeBlocks = (lang) => {
    var _a, _b;
    return (_b = (_a = loadedLangInfo[lang]) === null || _a === void 0 ? void 0 : _a[autoLoadMdCodeBlocksKey]) !== null && _b !== void 0 ? _b : false;
};
const codeBlockMap = {
    js: 'javascript',
    ts: 'typescript',
    style: 'atdot',
    yml: 'yaml',
    sh: 'shellscript',
    shell: 'shellscript',
    bash: 'shellscript',
    py: 'python',
};
export const loadMdCodeBlocks = (lang, code) => {
    var _a, _b;
    const info = loadedLangInfo[lang];
    if (!(info === null || info === void 0 ? void 0 : info[autoLoadMdCodeBlocksKey]) || !(info === null || info === void 0 ? void 0 : info.embeddedLangsLazy)) {
        return false;
    }
    let loadStarted = false;
    codeBlockReg.lastIndex = 0;
    let match;
    while (match = codeBlockReg.exec(code)) {
        const bl = (_a = match[2]) === null || _a === void 0 ? void 0 : _a.toLowerCase();
        const blockLang = (_b = codeBlockMap[bl !== null && bl !== void 0 ? bl : '']) !== null && _b !== void 0 ? _b : bl;
        if (!blockLang || loadLangMap[blockLang] || !info.embeddedLangsLazy.includes(blockLang)) {
            continue;
        }
        loadShikiLangAsync(blockLang);
        loadStarted = true;
    }
    return loadStarted;
};
const codeBlockReg = /(^|\n)```\s*([\w\-]+)/g;
export const getShikiAsync = () => __awaiter(void 0, void 0, void 0, function* () {
    if (!defaultHighlighter) {
        defaultHighlighter = (() => __awaiter(void 0, void 0, void 0, function* () {
            const sh = yield import('shiki');
            return sh.createHighlighter({
                themes: ['dark-plus'],
                langs: [],
            });
        }))();
    }
    return defaultHighlighter;
});
export const useShiki = (language) => {
    const [sh, setSh] = useState(null);
    const [loadIndex, setLoadIndex] = useState(0);
    useEffect(() => {
        let m = true;
        getShikiAsync().then(v => {
            if (m) {
                setSh(v);
            }
        });
        return () => {
            m = false;
        };
    }, []);
    useEffect(() => {
        setLoadIndex(v => v + 1);
        if (!sh || !language) {
            return;
        }
        let m = true;
        loadShikiLangAsync(language).then(() => {
            if (m) {
                setLoadIndex(v => v + 1);
            }
        });
        return () => {
            m = false;
        };
    }, [language, sh]);
    useEffect(() => {
        let iv = undefined;
        let m = true;
        const sub = onLangLoad.subscribe(() => {
            iv = setTimeout(() => {
                clearTimeout(iv);
                if (m) {
                    setLoadIndex(v => v + 1);
                }
            }, 100);
        });
        return () => {
            sub.unsubscribe();
            m = false;
        };
    }, []);
    return { sh, loadIndex };
};
//# sourceMappingURL=shiki.js.map