"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CodeInput = exports.markdownCodeLineStartReg = exports.defaultCodeLineStartReg = void 0;
const tslib_1 = require("tslib");
const jsx_runtime_1 = require("react/jsx-runtime");
const at_dot_css_1 = require("@iyio/at-dot-css");
const common_1 = require("@iyio/common");
const react_common_1 = require("@iyio/react-common");
const react_1 = require("react");
const lib_design_tokens_1 = require("../lib/lib-design-tokens");
const LineNumbers_1 = require("./LineNumbers");
const shiki_1 = require("./shiki");
exports.defaultCodeLineStartReg = /^(\s*)/;
exports.markdownCodeLineStartReg = /^(\s*-?\s*)/;
/**
 * @acIgnore
 */
function CodeInput(_a) {
    var { tab = '    ', language: _language = 'auto', value, readOnly, valueOverride, disabled, onChange, onSubmit, onElem, onTextarea, onBlur, onNewLine, tall, lineStartReg = exports.defaultCodeLineStartReg, lineStartRegIndex = 1, lineNumbers, errors, parser, parserOptions, onParsed, logParsed, parsingDelayMs = 700, debugParser, bottomPadding = 500, fillScrollHeight, highlightPrefix, highlightSuffix } = _a, props = tslib_1.__rest(_a, ["tab", "language", "value", "readOnly", "valueOverride", "disabled", "onChange", "onSubmit", "onElem", "onTextarea", "onBlur", "onNewLine", "tall", "lineStartReg", "lineStartRegIndex", "lineNumbers", "errors", "parser", "parserOptions", "onParsed", "logParsed", "parsingDelayMs", "debugParser", "bottomPadding", "fillScrollHeight", "highlightPrefix", "highlightSuffix"]);
    const [language, setLanguage] = (0, react_1.useState)(_language);
    (0, react_1.useEffect)(() => {
        setLanguage(_language);
    }, [_language]);
    (0, react_1.useEffect)(() => {
        if (_language === 'text' && jsonStart.test(value) && jsonEnd.test(value)) {
            setLanguage('json');
        }
    }, [value, _language]);
    const { sh, loadIndex } = (0, shiki_1.useShiki)(language);
    const [parsingErrors, setParsingErrors] = (0, react_1.useState)(undefined);
    const [code, setCode] = (0, react_1.useState)(null);
    const [textArea, setTextArea] = (0, react_1.useState)(null);
    const refs = (0, react_1.useRef)({ onParsed });
    refs.current.onParsed = onParsed;
    (0, react_1.useEffect)(() => {
        setParsingErrors(undefined);
        if (!code || !textArea || !sh) {
            return;
        }
        const fullValue = (highlightPrefix !== null && highlightPrefix !== void 0 ? highlightPrefix : '') + value + (highlightSuffix !== null && highlightSuffix !== void 0 ? highlightSuffix : '');
        let lineOptions = [];
        if (highlightPrefix) {
            const n = (0, common_1.getSubstringCount)(highlightPrefix, '\n');
            for (let i = 1; i <= n; i++) {
                lineOptions.push({
                    line: i,
                    classes: ['hide-prefix']
                });
            }
        }
        if (highlightSuffix) {
            const n = (0, common_1.getSubstringCount)(highlightSuffix, '\n');
            const lineCount = (0, common_1.getSubstringCount)(fullValue, '\n');
            for (let i = 0; i < n; i++) {
                lineOptions.push({
                    line: lineCount - i + 1,
                    classes: ['hide-suffix']
                });
            }
        }
        let iv = undefined;
        let highlighted;
        if ((0, shiki_1.supportsMdCodeBlocks)(language)) {
            (0, shiki_1.loadMdCodeBlocks)(language, fullValue);
        }
        try {
            highlighted = sh.codeToHtml(fullValue, {
                lang: sh.getLoadedLanguages().includes(language) ? language : 'text',
                theme: 'dark-plus',
                transformers: [{
                        line: function (elem, line) {
                            for (const lo of lineOptions) {
                                if (lo.line === line && lo.classes) {
                                    this.addClassToHast(elem, lo.classes);
                                }
                            }
                        }
                    }]
            });
        }
        catch (ex) {
            console.error('code to html failed', ex);
            return;
        }
        code.innerHTML = highlighted;
        const codeElem = code.querySelector('code');
        let minWidth = 0;
        if (codeElem) {
            minWidth = processLines(codeElem);
        }
        textArea.style.minWidth = minWidth + 'px';
        if (parser) {
            iv = setTimeout(() => {
                var _a, _b;
                try {
                    const r = parser(fullValue, Object.assign({ debug: debugParser ? debugParser === true ? console.info : debugParser : undefined }, parserOptions));
                    if (logParsed) {
                        console.info('CodeInput parsing result', r);
                    }
                    (_b = (_a = refs.current).onParsed) === null || _b === void 0 ? void 0 : _b.call(_a, r);
                    setParsingErrors(r.error ? [r.error] : undefined);
                    if (r.error) {
                        console.info('⛔️ CodeInput parsing error', r.error);
                        console.info(r.error.near);
                        code.innerHTML = sh.codeToHtml(fullValue, { lang: language, theme: 'dark-plus', transformers: [{
                                    line: function (elem, line) {
                                        var _a;
                                        if (line === ((_a = r.error) === null || _a === void 0 ? void 0 : _a.lineNumber)) {
                                            this.addClassToHast(elem, 'CodeInput-errorLine');
                                        }
                                        for (const lo of lineOptions) {
                                            if (lo.line === line && lo.classes) {
                                                this.addClassToHast(elem, lo.classes);
                                            }
                                        }
                                    }
                                }] }).replace(/class="[^"]*CodeInput-errorLine[^"]*"[^>]*>/g, v => {
                            var _a, _b, _c, _d, _e;
                            return `${v}<div class="CodeInput-error">${(0, common_1.escapeHtml)((_c = (_b = (_a = r.error) === null || _a === void 0 ? void 0 : _a.message) === null || _b === void 0 ? void 0 : _b.replace(/\n/g, '\\n').replace(/\r/g, '\\r')) !== null && _c !== void 0 ? _c : '')}</div><div class="CodeInput-errorCol">${'&nbsp;'.repeat(((_e = (_d = r.error) === null || _d === void 0 ? void 0 : _d.col) !== null && _e !== void 0 ? _e : 0) - 1) + '_'}</div>`;
                        });
                        const codeElem = code.querySelector('code');
                        if (codeElem) {
                            processLines(codeElem);
                        }
                    }
                }
                catch (ex) {
                    setParsingErrors([0]);
                }
            }, parsingDelayMs);
        }
        else {
            setParsingErrors(undefined);
            return undefined;
        }
        return () => {
            clearTimeout(iv);
        };
    }, [
        code, textArea, valueOverride, value, language, parser, sh, loadIndex,
        parsingDelayMs, logParsed, debugParser, parserOptions,
        highlightPrefix, highlightSuffix
    ]);
    (0, react_1.useEffect)(() => {
        onElem === null || onElem === void 0 ? void 0 : onElem(code);
    }, [onElem, code]);
    (0, react_1.useEffect)(() => {
        onTextarea === null || onTextarea === void 0 ? void 0 : onTextarea(textArea);
    }, [onTextarea, textArea]);
    const onKeyDown = (0, react_1.useCallback)((e) => {
        var _a;
        if (disabled) {
            e.preventDefault();
            return;
        }
        if (!textArea) {
            return;
        }
        switch (e.key) {
            case "Tab": {
                e.preventDefault();
                const value = (textArea.value.substring(0, textArea.selectionStart) +
                    tab +
                    textArea.value.substring(textArea.selectionStart));
                const s = textArea.selectionStart + tab.length;
                textArea.value = value;
                textArea.selectionStart = s;
                textArea.selectionEnd = s;
                textArea.focus();
                onChange === null || onChange === void 0 ? void 0 : onChange(value);
                break;
            }
            case "Enter": {
                const value = (textArea.value.substring(0, textArea.selectionStart) +
                    textArea.value.substring(textArea.selectionStart));
                if (e.metaKey || e.ctrlKey) {
                    e.preventDefault();
                    const s = textArea.selectionStart;
                    textArea.value = value;
                    if (s >= 0) {
                        textArea.selectionStart = s;
                        textArea.selectionEnd = s;
                        textArea.focus();
                    }
                    onSubmit === null || onSubmit === void 0 ? void 0 : onSubmit(value);
                }
                else {
                    const s = textArea.selectionStart;
                    if (lineStartReg && s > 0 && s === textArea.selectionEnd) {
                        const i = textArea.value.lastIndexOf('\n', s - 1);
                        if (i != -1) {
                            const prevLine = textArea.value.substring(i + 1, s);
                            const lineStart = (_a = lineStartReg.exec(prevLine)) === null || _a === void 0 ? void 0 : _a[lineStartRegIndex];
                            if (lineStart) {
                                e.preventDefault();
                                textArea.value = textArea.value.substring(0, s) + '\n' + lineStart + textArea.value.substring(s);
                                textArea.selectionStart = s + lineStart.length + 1;
                                textArea.selectionEnd = s + lineStart.length + 1;
                                onChange === null || onChange === void 0 ? void 0 : onChange(textArea.value);
                                textArea.focus();
                            }
                        }
                    }
                    onNewLine === null || onNewLine === void 0 ? void 0 : onNewLine(value);
                }
                break;
            }
        }
    }, [textArea, tab, onChange, onSubmit, onNewLine, disabled, lineStartReg, lineStartRegIndex]);
    return ((0, jsx_runtime_1.jsx)(jsx_runtime_1.Fragment, { children: (0, jsx_runtime_1.jsxs)("div", { className: style.root({ tall, disabled, readOnly, lineNumbers: lineNumbers !== undefined }, null, props), style: {
                minHeight: fillScrollHeight ? `var(${react_common_1.scrollViewContainerMinHeightCssVar})` : undefined
            }, children: [lineNumbers && (0, jsx_runtime_1.jsx)(LineNumbers_1.LineNumbers, { count: (0, common_1.strLineCount)(value), errors: errors !== null && errors !== void 0 ? errors : parsingErrors }), (0, jsx_runtime_1.jsx)("div", { className: "CodeInput-content", children: (0, jsx_runtime_1.jsxs)("div", { children: [(0, jsx_runtime_1.jsx)("div", { ref: setCode, className: (0, common_1.cn)("no-select", language === 'auto' ? undefined : `language-${language}`), style: { marginBottom: bottomPadding } }, language), (0, jsx_runtime_1.jsx)("textarea", { spellCheck: false, ref: setTextArea, onKeyDown: onKeyDown, onChange: e => onChange === null || onChange === void 0 ? void 0 : onChange(e.target.value), onBlur: e => onBlur === null || onBlur === void 0 ? void 0 : onBlur(e.target.value), value: value, readOnly: readOnly })] }) })] }) }));
}
exports.CodeInput = CodeInput;
const style = (0, at_dot_css_1.atDotCss)({ name: 'CodeInput', css: `
    .CodeInput{
        display:flex;
        border-radius:8px;
        transition:opacity 0.1s ease-in-out;
        background:#1E1E1E;
    }
    .CodeInput textarea{
        all:unset;
    }
    .CodeInput.tall{
        min-height:200px;
    }
    .CodeInput.disabled{
        opacity:0.4;
    }
    .CodeInput.disabled textarea{
        opacity:0;
    }
    .CodeInput code, .CodeInput textarea{
        margin:0 !important;
        padding: 0 !important;
        display:block;
        white-space:pre;
        font-family:Courier !important;
        font-size:${(0, lib_design_tokens_1.dt)().codeFontSize}px !important;
        line-height:${(0, lib_design_tokens_1.dt)().codeLineHeight}px !important;
        min-height:${(0, lib_design_tokens_1.dt)().codeLineHeight}px;
    }
    .CodeInput code *{
        font-size:${(0, lib_design_tokens_1.dt)().codeFontSize}px !important;
        line-height:${(0, lib_design_tokens_1.dt)().codeLineHeight}px !important;
    }
    .CodeInput pre{
        margin:0 !important;
        padding:0 !important;
        display:block;
    }
    .CodeInput pre,.CodeInput code{
        background: none !important;
    }
    .CodeInput textarea{
        position:absolute;
        left:0;
        top:0;
        width:100%;
        height:100%;
        overflow:hidden;
        overflow:clip;
        border:none;
        background:none;
        resize:none;
        color:transparent;
        caret-color: #ffffffcc;
        outline:none;
        outline-width:0;
        cursor:text;
    }
    .CodeInput.readOnly textarea{
        pointer-events:none;
    }
    .CodeInput .no-select{
        pointer-events:none;
    }
    .CodeInput.readOnly .no-select{
        pointer-events:auto;
    }
    .CodeInput-content{
        display:flex;
        flex-direction:column;
        overflow-x:auto;
        flex:1;
    }
    .CodeInput-content > div{
        position:relative;
        min-height:100%;
    }
    .CodeInput.lineNumbers .CodeInput-content > div{
        margin-left:0.5rem !important;
    }

    .CodeInput-errorLine{
        position:relative;
    }
    .CodeInput-errorLine > .CodeInput-error{
        position:absolute;
        left:calc( 100% + 1rem);
        font-size:12px !important;
        line-height:12px !important;
        display:flex;
        align-items:center;
        background-color:#ff000033;
        top:-0.2rem;
        bottom:-0.2rem;
        padding:0 0.4rem;
        border-radius:4px;
    }
    .CodeInput-errorCol{
        position:absolute;
        left:0;
        top:0;
        color:#ff000088;
    }
    .CodeInput .hide-prefix, .CodeInput .hide-suffix{
        display:none;
    }
` });
const processLines = (codeElem) => {
    let minWidth = 0;
    for (let i = 0; i < codeElem.children.length; i++) {
        const item = codeElem.children.item(i);
        if (!item) {
            continue;
        }
        if (item.classList.contains('hide-prefix')) {
            const text = item.nextSibling;
            if (text instanceof Text) {
                text.remove();
            }
            item.remove();
            continue;
        }
        if (item.classList.contains('hide-suffix')) {
            const text = item.previousSibling;
            if (text instanceof Text) {
                text.remove();
            }
            item.remove();
            continue;
        }
        const w = item.offsetWidth;
        if (w && w > minWidth) {
            minWidth = w;
        }
    }
    return minWidth;
};
const jsonStart = /^\s*\{/;
const jsonEnd = /\}\s*$/;
//# sourceMappingURL=CodeInput.js.map