"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useShiki = exports.getShikiAsync = exports.loadMdCodeBlocks = exports.supportsMdCodeBlocks = exports.loadShikiLangAsync = void 0;
const tslib_1 = require("tslib");
const react_1 = require("react");
const rxjs_1 = require("rxjs");
const langs_1 = require("shiki/langs");
const atDotCss_1 = require("./grammar/atDotCss");
const convo_1 = require("./grammar/convo");
const mdx_1 = require("./grammar/mdx");
let defaultHighlighter;
const autoLoadMdCodeBlocksKey = 'autoLoadMdCodeBlocks';
const autoLoadMdCodeBlocksList = [
    'markdown',
];
const loadedLangInfo = {};
const loadLangMap = {};
const onLangLoad = new rxjs_1.Subject();
const loadShikiLangAsync = (name) => {
    var _a;
    return (_a = loadLangMap[name]) !== null && _a !== void 0 ? _a : (loadLangMap[name] = _loadShikiLangAsync(0, name));
};
exports.loadShikiLangAsync = loadShikiLangAsync;
const langDeps = {
//mdx:['tsx'],
//convo:['json','xml','javascript','python'],
};
const _loadShikiLangAsync = (depth, name) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    var _a, _b;
    if (depth > 10 || name === 'elm' || name === 'erlang') {
        return false;
    }
    const sh = yield (0, exports.getShikiAsync)();
    if (sh.getLoadedLanguages().includes(name)) {
        return false;
    }
    const custom = (name === 'convo' ?
        convo_1.convoGrammar
        : name === 'atdot' ?
            atDotCss_1.atDotCssGrammar
            : name === 'mdx' ?
                mdx_1.mdxGrammar
                :
                    null);
    try {
        yield sh.loadLanguage(custom !== null && custom !== void 0 ? custom : name);
        onLangLoad.next(name);
    }
    catch (_c) {
        //
    }
    const bundled = custom ? [custom] : ((_b = (yield ((_a = langs_1.bundledLanguages[name]) === null || _a === void 0 ? void 0 : _a.call(langs_1.bundledLanguages)))) === null || _b === void 0 ? void 0 : _b.default);
    const depList = langDeps[name];
    if (depList) {
        for (const dep of depList) {
            yield _loadShikiLangAsync(depth + 1, dep);
        }
    }
    if (bundled) {
        for (const b of bundled) {
            loadedLangInfo[b.name] = {
                embeddedLangsLazy: b.embeddedLangsLazy,
                [autoLoadMdCodeBlocksKey]: b[autoLoadMdCodeBlocksKey] || autoLoadMdCodeBlocksList.includes(b.name),
            };
            if (b.embeddedLangs) {
                for (const e of b.embeddedLangs) {
                    yield _loadShikiLangAsync(depth + 1, e);
                }
            }
        }
    }
    return true;
});
const supportsMdCodeBlocks = (lang) => {
    var _a, _b;
    return (_b = (_a = loadedLangInfo[lang]) === null || _a === void 0 ? void 0 : _a[autoLoadMdCodeBlocksKey]) !== null && _b !== void 0 ? _b : false;
};
exports.supportsMdCodeBlocks = supportsMdCodeBlocks;
const codeBlockMap = {
    js: 'javascript',
    ts: 'typescript',
    style: 'atdot',
    yml: 'yaml',
    sh: 'shellscript',
    shell: 'shellscript',
    bash: 'shellscript',
    py: 'python',
};
const loadMdCodeBlocks = (lang, code) => {
    var _a, _b;
    const info = loadedLangInfo[lang];
    if (!(info === null || info === void 0 ? void 0 : info[autoLoadMdCodeBlocksKey]) || !(info === null || info === void 0 ? void 0 : info.embeddedLangsLazy)) {
        return false;
    }
    let loadStarted = false;
    codeBlockReg.lastIndex = 0;
    let match;
    while (match = codeBlockReg.exec(code)) {
        const bl = (_a = match[2]) === null || _a === void 0 ? void 0 : _a.toLowerCase();
        const blockLang = (_b = codeBlockMap[bl !== null && bl !== void 0 ? bl : '']) !== null && _b !== void 0 ? _b : bl;
        if (!blockLang || loadLangMap[blockLang] || !info.embeddedLangsLazy.includes(blockLang)) {
            continue;
        }
        (0, exports.loadShikiLangAsync)(blockLang);
        loadStarted = true;
    }
    return loadStarted;
};
exports.loadMdCodeBlocks = loadMdCodeBlocks;
const codeBlockReg = /(^|\n)```\s*([\w\-]+)/g;
const getShikiAsync = () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    if (!defaultHighlighter) {
        defaultHighlighter = (() => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
            const sh = yield Promise.resolve().then(() => require('shiki'));
            return sh.createHighlighter({
                themes: ['dark-plus'],
                langs: [],
            });
        }))();
    }
    return defaultHighlighter;
});
exports.getShikiAsync = getShikiAsync;
const useShiki = (language) => {
    const [sh, setSh] = (0, react_1.useState)(null);
    const [loadIndex, setLoadIndex] = (0, react_1.useState)(0);
    (0, react_1.useEffect)(() => {
        let m = true;
        (0, exports.getShikiAsync)().then(v => {
            if (m) {
                setSh(v);
            }
        });
        return () => {
            m = false;
        };
    }, []);
    (0, react_1.useEffect)(() => {
        setLoadIndex(v => v + 1);
        if (!sh || !language) {
            return;
        }
        let m = true;
        (0, exports.loadShikiLangAsync)(language).then(() => {
            if (m) {
                setLoadIndex(v => v + 1);
            }
        });
        return () => {
            m = false;
        };
    }, [language, sh]);
    (0, react_1.useEffect)(() => {
        let iv = undefined;
        let m = true;
        const sub = onLangLoad.subscribe(() => {
            iv = setTimeout(() => {
                clearTimeout(iv);
                if (m) {
                    setLoadIndex(v => v + 1);
                }
            }, 100);
        });
        return () => {
            sub.unsubscribe();
            m = false;
        };
    }, []);
    return { sh, loadIndex };
};
exports.useShiki = useShiki;
//# sourceMappingURL=shiki.js.map